@@ -28,11 +28,10 @@
         LOCK(((Fl_Window *)self)->make_current();)                                                 \
     }                                                                                              \
     void widget##_set_icon(widget *self, const void *image) {                                      \
-        LOCK(auto old = (Fl_Image *)self->icon(); self->icon(((Fl_Image *)image)->copy());         \
-             delete old;)                                                                          \
+        LOCK(self->icon((const Fl_RGB_Image *)((Fl_Image *)image));)                               \
     }                                                                                              \
     void *widget##_icon(const widget *self) {                                                      \
-        return ((Fl_Image *)self->icon())->copy();                                                 \
+        return (Fl_Image *)self->icon();                                                           \
     }                                                                                              \
     void widget##_set_cursor(widget *self, int cursor) {                                           \
         LOCK(self->cursor((Fl_Cursor)cursor);)                                                     \
@@ -87,10 +86,14 @@
         LOCK(self->hotspot(wid))                                                                   \
     }                                                                                              \
     void widget##_set_shape(widget *self, const void *image) {                                     \
-        LOCK(auto old = self->shape(); self->shape(((Fl_Image *)image)->copy()); delete old;)      \
+        LOCK(auto old = self->shape(); if (!image) self->shape(NULL);                              \
+             else self->shape(((Fl_Image *)image)->copy()); delete old;)                           \
     }                                                                                              \
     const void *widget##_shape(widget *self) {                                                     \
-        return (const void *)((Fl_Image *)self->shape())->copy();                                  \
+        auto temp = self->shape();                                                                 \
+        if (!temp)                                                                                 \
+            return NULL;                                                                           \
+        return ((Fl_Image *)temp)->copy();                                                         \
     }                                                                                              \
     int widget##_x_root(const widget *self) {                                                      \
         return self->x_root();                                                                     \
